@@ -120,18 +120,21 @@ print.vcov.hopit <- function(x, digits = 3L, ...){
 #' @export
 #' @author Maciej J. Danko
 #' @useDynLib hopit
-#' @usage \method{summary}{hopit}(object, robust.se = TRUE, ...)
+#' @usage \method{summary}{hopit}(object, robust.se, ...)
 #' @method summary hopit
 #' @keywords internal
 #' @importFrom Rcpp evalCpp
-summary.hopit <- function(object, robust.se = TRUE, ...){
+summary.hopit <- function(object, robust.se, ...){
+  if (missing(robust.se)) {
+    if (length(object$design)) robust.se <- FALSE else robust.se <- TRUE
+  }
   varcov <- vcov.hopit(object, robust.se, ...)
   robust.se <- attr(varcov, 'robust.vcov')
   dvcov <- diag(varcov)
   if (any(dvcov<0)) warning(hopit_msg(43),call.=NA)
   SE <- suppressWarnings(sqrt(abs(dvcov)))
   if (length(object$design)){
-    cat(hopit_msg(44))
+    message(hopit_msg(44))
   }
   if ((!robust.se) && (any(is.na(SE))) && !(length(object$design)))
     warning(call. = FALSE, hopit_msg(45))
@@ -176,6 +179,230 @@ print.summary.hopit <- function(x, ...){
   invisible(NULL)
 }
 
+#' @keywords internal
+#' @export
+#' @method print hopitDW
+#' @noRd
+print.hopitDW <- function(x, digits=4, quote=FALSE, ...){
+  x1 <- as.matrix(format(round(as.vector(x),digits),nsmall=digits, digits=digits,
+         scientific = FALSE))
+  dimnames(x1) <- dimnames(x)
+  print.default(x1, quote=quote, digits=digits, ...)
+}
+
+#' @keywords internal
+#' @export
+#' @method summary hopitDW
+#' @noRd
+summary.hopitDW<-function(object, ...){
+  x <- data.frame(cbind('Std. coef'=as.vector(object), attr(object,'Ptab')),
+                  check.names = FALSE)
+  class(x) <- c('summary.hopitDW','data.frame')
+  attr(x,'legend') <- attr(object,'legend')
+  return(x)
+}
+
+#' @keywords internal
+#' @export
+#' @method print summary.hopitDW
+#' @noRd
+print.summary.hopitDW <- function(x, digits=4, show.coef.names=TRUE, ...){
+  if (show.coef.names) {
+    g <- data.frame('Coefficient name' = x[,2],
+                  'Standardized coeficient'=
+                    format(round(x[,1],digits),nsmall=digits, digits=digits,
+                           scientific = FALSE),
+                  'Pr(>|z|)' = format(round(x[,3],digits),
+                         nsmall=digits, digits=digits, scientific = FALSE),
+                  x[,4],
+                  fix.empty.names = FALSE, check.names = FALSE)
+  } else {
+    g <- data.frame('Standardized coeficient'=
+                      format(round(x[,1],digits), nsmall=digits, digits=digits,
+                             scientific = FALSE),
+                    'Pr(>|z|)' = format(round(x[,3],digits),
+                          nsmall=digits, digits=digits, scientific = FALSE),
+                    x[,4],
+                    fix.empty.names = FALSE, check.names = FALSE)
+  }
+  rownames(g)<-rownames(x)
+  print(g)
+  cat("---\nSignif. codes: ",attr(x,'legend'),'\n')
+}
+
+#' Plotting standardized coefficients
+#' @keywords internal
+#' @export
+#' @method plot hopitDW
+#' @param x a object generated by \code{\link{standardizeCoef}} function.
+#' @param ordered a logical indicating whether to sort the disability weights.
+#' @param show.signif show significance codes.
+#' @param mar,oma graphic parameters, see \code{\link{par}}.
+#' @param ylab,xlab,density,angle,col,las,... arguments passed to \code{\link{barplot}}.
+#' @importFrom graphics text
+#' @author Maciej J. Danko
+plot.hopitDW <- function(x,
+                         ordered = TRUE,
+                         show.signif = TRUE,
+                         mar = c(10, 4, 1.5, 1),
+                         oma = c(0, 0, 0, 0),
+                         ylab = "Disability weight",
+                         xlab = "",
+                         density = 20,
+                         angle = 45,
+                         col = 'orange',
+                         las = 3, ...){
+  x <- summary.hopitDW(x)
+  if (ordered) {
+    oz <- order(x[,1], decreasing = TRUE)
+    x <- x[oz,]
+  }
+  if (length(mar) || length(oma)) {
+    opar <- graphics::par(c("mar", "oma"))
+    if (length(mar)) graphics::par(mar = mar)
+    if (length(oma)) graphics::par(oma = oma)
+  }
+  rr <- graphics::barplot(x[,1], las = las, names.arg = rownames(x), ylab = ylab,
+                          angle=angle, col=col, density=density, ...)
+  if (show.signif) graphics::text(rr,x[,1],paste('',x[,4]),srt=90, xpd=NA, adj=0, col='darkred')
+}
+
+#' Plotting Latent Index
+#' @keywords internal
+#' @export
+#' @method plot hopitHI
+#' @param x a object generated by \code{\link{latentIndex}} function.
+#' @param response X-axis plotting option; choose \code{'data'} for the raw responses and \code{'fitted'} for the responses reclassified by the model.
+#' @param xlab a label of the x-axis.
+#' @param ylab a label of the y-axis.
+#' @param ... further parameters passed to the \code{\link{plot}} function.
+#' @author Maciej J. Danko
+plot.hopitHI<-function(x,
+                       response = c('data','fitted'),
+                       xlab = '', ylab = 'Latent index', ...){
+  mi <- attr(x, 'model.info')
+  response <- tolower(match.arg(response))
+  if (response=='data') YY <- mi$y_i else
+    if (response=='fitted') YY <- mi$Ey_i else
+      stop(hopit_msg(83),call.=NULL)
+  graphics::plot(YY, x ,las=3, ylab=ylab, xlab=xlab,...)
+}
+
+#' @keywords internal
+#' @export
+#' @method print hopitHI
+#' @noRd
+print.hopitHI <- function(x, digits = 2, quote=FALSE, ...){
+  print.default(format(round(as.vector(x), digits),
+                       scientific=FALSE, digits=digits,
+                       nsmall=digits), quote=quote, ...)
+}
+
+#' @keywords internal
+#' @export
+#' @method summary hopitHI
+#' @noRd
+summary.hopitHI <- function(object, breaks = seq(0,1,length.out = 21), ...){
+  z<-cut(object, include.lowest = FALSE, breaks=breaks)
+  z<-table(z)
+  dimnames(z)<-unname(dimnames(z))
+  z
+}
+
+#' Plotting Cut-Points
+#' @keywords internal
+#' @export
+#' @method plot hopitCP
+#' @param decreasing.levels a logical indicating whether self-reported health classes are ordered in decreasing order.
+#' @param plotf a logical indicating whether to plot the results.
+#' @param XLab,XLab.cex a label of the x axis and it's size.
+#' @param YLab,YLab.cex a label of the y axis and it's size.
+#' @param border.lwd,border.lty,border.col graphic parameters for vertical lines used to plot cut-points.
+#' @param mar,oma graphic parameters, see \code{\link{par}}.
+#' @param group.labels.type a position of the legend. One of \code{middle}, \code{border}, or \code{none}.
+#' @param ... further plotting arguments.
+#' @author Maciej J. Danko
+plot.hopitCP<-function(x,
+                       decreasing.levels=x$decreasing.levels,
+                       mar=c(4,4,1,1),
+                       oma=c(0,0,0,0),
+                       XLab='Health index',
+                       XLab.cex=1.1,
+                       YLab='Counts',
+                       YLab.cex=1.1,
+                       border.col=2,
+                       border.lty=2,
+                       border.lwd=1.5,
+                       group.labels.type=c('middle','border','none'),
+                       ...){
+  if (decreasing.levels) dorev <- rev else dorev <- identity
+  lv <- dorev(as.character(levels(attr(x,'y_i'))))
+  Nm <- paste(lv[-length(lv)],lv[-1],sep=' | ')
+  Nm <- sapply(Nm, function(k) bquote(bold(.(k))))
+  group.labels.type<-tolower(group.labels.type[1])
+  if (group.labels.type %notin%  c('middle','border','none'))
+    stop(hopit_msg(84),call.=NULL)
+  opar <- graphics::par(c('mar','oma'))
+  graphics::par(mar=mar, oma=oma)
+
+  z<-graphics::hist(x$h.index, 100,xlab='',ylab='' ,
+                    main='', yaxs='i', col=grDevices::grey(0.4, alpha = 0.5),
+                    border=grDevices::grey(0.4, alpha = 0.5))
+  if (group.labels.type == 'border') {
+    for (j in seq_along(Nm)) graphics::text(x=R1[j],y=(1.1*max(z$counts))/2,
+                                            labels=Nm[[j]],
+                                            srt=90,pos=2,offset=0.67,col=2)
+  } else if (group.labels.type == 'middle'){
+    R1 <- x$cutpoints
+    R11=-diff(c(0,R1,1))/2+c(R1,1)+graphics::strheight('S',units='figure')/2
+    for (j in seq_along(lv)) graphics::text(x=R11[j],
+                                            y=(3*1.1*max(z$counts))/4,
+                                            labels=lv[j],
+                                            srt=90,
+                                            pos=3,
+                                            offset=0.67,
+                                            col=2)
+  }
+  graphics::box()
+  graphics::abline(v=R1,lwd=border.lwd,col=border.col,lty=border.lty)
+  graphics::mtext(XLab, 1, cex=XLab.cex, line = 2.5)
+  graphics::mtext(YLab, 2, cex=YLab.cex, line = 2.5)
+  suppressWarnings(graphics::par(opar))
+}
+
+#' Plotting getLevels object
+#' @keywords internal
+#' @export
+#' @method plot hopitLV
+#' @param x aobject generated by \code{\link{getLevels}}.
+#' @param mar,oma graphic parameters, see \code{\link{par}}.
+#' @param YLab,YLab.cex a label for the y-axis and it's size.
+#' @param legbg a legend background color. See \code{bg} parameter in \code{\link{legend}}.
+#' @param legbty a legend box type. See \code{bty} parameter in \code{\link{legend}}.
+#' @param las the style of axis labels, see \code{\link{par}}.
+#' @param ... further plotting arguments.
+#' @author Maciej J. Danko
+plot.hopitLV<-function(x,
+                      mar = c(7,2,1.5,0.5), oma = c(0,3,0,0),
+                      YLab = 'Fraction [%]',
+                      YLab.cex = 1.1,
+                      legbg = grDevices::adjustcolor('white',alpha.f=0.4),
+                      legbty = 'o',
+                      las = 3,
+                      ...){
+
+    opar <- graphics::par(c('mar','oma','mfrow'))
+    graphics::par(mfrow=c(1,2))
+    graphics::par(mar=mar,oma=oma)
+    graphics::barplot(t(x$original),las=las,main='Original')
+    graphics::barplot(t(x$adjusted),las=las,main='Adjusted', legend.text=TRUE,
+                      args.legend = list(x='center', box.col=NA,
+                                         bg=legbg, bty=legbty))
+    graphics::par(mfrow=c(1,1))
+    graphics::par(mar=mar,oma=rep(0,4))
+    graphics::mtext(YLab,2,cex=YLab.cex)
+    suppressWarnings(graphics::par(opar))
+}
 
 #' Extracting a log likelihood of the fitted model
 #'
@@ -432,7 +659,7 @@ print.anova.hopit <- function(x, ...){
 #' lrt1 <- lrt.hopit(full = model2, nested = model1)
 #' lrt1
 #'
-#' # print the results in shorter form
+#' # print the results in a shorter form
 #' print(lrt1, short = TRUE)
 #'
 #' # equivalently
@@ -513,22 +740,22 @@ print.lrt.hopit <- function(x, short = FALSE, ...){
     cat("--",hopit_msg(65), deparse(x$nested$latent.formula), fill = TRUE)
     cat("--",hopit_msg(66), deparse(x$nested$thresh.formula), fill = TRUE)
     cat("--",hopit_msg(70),x$nested$hasdisp, fill=TRUE)
+    cat('\n')
   }
-  #uzyc signif
   cat(hopit_msg(59))
-  if (length(x$df)) {
-    out <- t(as.matrix(c('Chi^2' = unname(x$chisq), df = unname(x$df),
-                         'Pr(>Chi^2)' = unname(x$pval))))
-    out2 <- NULL
-  } else {
-    out <- t(as.matrix(c('Chi^2' = unname(x$chisq),
-                         'Pr(>Chi^2)' = unname(x$pval))))
-    out2 <- x$scalef
-  }
+  # if (length(x$df)) {
+  out <- t(as.matrix(c('Chi^2' = unname(x$chisq), df = unname(x$df),
+                       'Pr(>Chi^2)' = unname(x$pval))))
+  #  out2 <- NULL
+  # else {
+  #   out <- t(as.matrix(c('Chi^2' = unname(x$chisq),
+  #                        'Pr(>Chi^2)' = unname(x$pval))))
+  #   out2 <- x$scalef
+  # }
   row.names(out) <- ''
   stats::printCoefmat(out, signif.stars = TRUE, P.values = TRUE,
                   has.Pvalue = TRUE, digits = 5L, dig.tst = 3L, tst.ind = 1L)
-  if (length(out2)) print(paste(hopit_msg(63),out2))
+  # if (length(out2)) print(paste(hopit_msg(63),out2))
   invisible(NULL)
 }
 
